@@ -1,13 +1,11 @@
 package Ado;
-use Mojo::Base -strict;
-
 use Mojo::Base 'Mojolicious';
 use File::Spec::Functions qw(splitdir catdir catfile);
-use Mojo::Util 'class_to_path';
 use List::Util 'first';
+use Mojo::Util 'class_to_path';
 
 our $AUTHORITY = 'cpan:BEROV';
-our $VERSION   = '0.933';
+our $VERSION   = '0.935';
 our $CODENAME  = 'U+2C0A GLAGOLITIC CAPITAL LETTER INITIAL IZHE (Ⰺ)';
 
 use Ado::Control;
@@ -17,8 +15,10 @@ my $CLASS = __PACKAGE__;
 has ado_home => sub {
     my @home = splitdir $INC{class_to_path $CLASS};
     while (pop @home) {
-        return Mojo::Home->new->parts([@home])
-          if -s catfile(@home, 'bin', lc $CLASS);    # bin/..
+        if (-s catfile(@home, 'bin', lc $CLASS)) {    # bin/..
+            local $ENV{MOJO_HOME} = catdir(@home);
+            return Mojo::Home->new->detect();
+        }
     }
     Carp::croak("$CLASS installation directory not found!");
 };
@@ -27,16 +27,7 @@ sub CODENAME { return $CODENAME }
 has sessions => sub { Ado::Sessions::get_instance(shift->config) };
 
 has home => sub {
-    my ($app) = @_;
-    my $class = ref $app;
-    return $app->SUPER::home if $ENV{MOJO_HOME};     # MOJO_HOME was forced
-    my @home    = splitdir $INC{class_to_path $class};
-    my $moniker = $app->moniker;
-    while (pop @home) {
-        return Mojo::Home->new->parts([@home])
-          if -s catfile(@home, 'bin', $moniker);     # bin/..
-    }
-    return $app->SUPER::home;                        #fallback to Mojo::Home
+    return Mojo::Home->new->detect();                 #fallback to Mojo::Home
 };
 
 
@@ -47,10 +38,10 @@ sub _initialise {
     my $ado_home = $app->ado_home;
 
     # add paths to bundled files if needed.
-    my $templates_dir  = $ado_home->rel_dir('templates');
-    my $site_templates = $home->rel_dir('site_templates');
+    my $templates_dir  = $ado_home->rel_file('templates');
+    my $site_templates = $home->rel_file('site_templates');
     my $renderer_paths = $app->renderer->paths;
-    my $public_dir     = $ado_home->rel_dir('public');
+    my $public_dir     = $ado_home->rel_file('public');
     my $static_paths   = $app->static->paths;
     push @$renderer_paths, $templates_dir
       unless (first { $_ eq $templates_dir } @$renderer_paths);
@@ -75,7 +66,11 @@ sub startup {
 #load ado.conf
 sub load_config {
     my ($app) = @_;
-    $ENV{MOJO_CONFIG} //= catfile($app->home, 'etc', $app->moniker . '.conf');
+    my $app_config = $app->home->rel_file('etc/' . $app->moniker . '.conf');
+    $ENV{MOJO_CONFIG} //=
+      -s $app_config
+      ? $app_config
+      : $app->ado_home->rel_file('etc/' . lc($CLASS) . '.conf');
     $app->plugin('Config');
     return $app;
 }
